import React, { useState, useEffect } from 'react'
import { Link, useLocation } from 'react-router-dom'
import { Disclosure } from '@headlessui/react'

// Navigation items configuration
// This can be moved to a separate file for better organization

/**
 * Navigation configuration for the main menu
 * Each item defines a name and href path for routing
 */
const navigation = [
  { name: 'Home', href: '/' },
  { name: 'Portfolio', href: '/portfolio' },
  { name: 'Artists', href: '/artists' },
  { name: 'Booking', href: '/booking' },
  { name: 'Aftercare', href: '/aftercare' },
  { name: 'FAQ', href: '/faq' },
  { name: 'Shop', href: '/shop' },
  { name: 'Contact', href: '/contact' },
]

/**
 * Header component that provides navigation and branding
 * Features responsive design with mobile menu and scroll-based styling
 */
function Header() {
  // Track scroll position to change header styling
  const [isScrolled, setIsScrolled] = useState(false)
  // Get current location for active link highlighting
  const location = useLocation()

  // Add scroll event listener to apply styling based on scroll position
  useEffect(() => {
    const handleScroll = () => {
      // Apply scrolled state when page is scrolled more than 50px
      setIsScrolled(window.scrollY > 50)
    }

    // Add event listener with passive flag for better performance
    window.addEventListener('scroll', handleScroll, { passive: true })
    // Clean up event listener on component unmount
    return () => window.removeEventListener('scroll', handleScroll)
  }, [])

  return (
    <Disclosure 
      as="header" 
      className={`fixed w-full z-50 transition-all duration-300 ${
        isScrolled ? 'bg-white/95 backdrop-blur-md shadow-lg' : 'bg-transparent'
      }`}
    >
      {({ open }) => (
        <>
          {/* Header Container */}
          <div className="section-padding">
            <div className="container-max">
              <div className="flex justify-between items-center h-16 lg:h-20">
                {/* Brand Logo */}
                <div className="flex-shrink-0">
                  <Link 
                    to="/" 
                    className="text-2xl lg:text-3xl font-serif font-bold tracking-tight hover:text-accent transition-all duration-300 transform hover:scale-105"
                    aria-label="Ink With Intention Studio - Home"
                  >
                    Ink With Intention
                  </Link>
                </div>

                {/* Desktop Navigation - Hidden on mobile */}
                <nav 
                  className="hidden lg:flex space-x-8" 
                  aria-label="Main navigation"
                >
                  {navigation.map((item) => (
                    <Link
                      key={item.name}
                      to={item.href}
                      className={`text-sm font-medium tracking-wide uppercase transition-colors duration-300 hover:text-accent ${
                        location.pathname === item.href ? 'text-accent' : 'text-black'
                      }`}
                      aria-current={location.pathname === item.href ? 'page' : undefined}
                    >
                      {item.name}
                    </Link>
                  ))}
                </nav>

                {/* Mobile Menu Toggle Button - Visible only on mobile */}
                <div className="lg:hidden">
                  <Disclosure.Button 
                    className="inline-flex items-center justify-center p-2 rounded-md text-black hover:text-accent hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-accent transition-colors duration-300"
                    aria-expanded={open}
                  >
                    <span className="sr-only">
                      {open ? 'Close main menu' : 'Open main menu'}
                    </span>
                    {open ? (
                      <svg 
                        className="block h-6 w-6" 
                        fill="none" 
                        viewBox="0 0 24 24" 
                        strokeWidth="1.5" 
                        stroke="currentColor" 
                        aria-hidden="true"
                      >
                        <path 
                          strokeLinecap="round" 
                          strokeLinejoin="round" 
                          d="M6 18L18 6M6 6l12 12" 
                        />
                      </svg>
                    ) : (
                      <svg 
                        className="block h-6 w-6" 
                        fill="none" 
                        viewBox="0 0 24 24" 
                        strokeWidth="1.5" 
                        stroke="currentColor" 
                        aria-hidden="true"
                      >
                        <path 
                          strokeLinecap="round" 
                          strokeLinejoin="round" 
                          d="M3.75 6.75h16.5M3.75 12h16.5m-16.5 5.25h16.5" 
                        />
                      </svg>
                    )}
                  </Disclosure.Button>
                </div>
              </div>
            </div>
          </div>

          {/* Mobile Navigation Panel - Shown when menu is open */}
          <Disclosure.Panel className="lg:hidden bg-white border-t border-gray-200">
            <nav className="section-padding py-4" aria-label="Mobile navigation">
              <div className="space-y-1">
                {navigation.map((item) => (
                  <Disclosure.Button
                    key={item.name}
                    as={Link}
                    to={item.href}
                    className={`block px-3 py-2 text-base font-medium tracking-wide uppercase transition-colors duration-300 hover:text-accent hover:bg-gray-50 ${
                      location.pathname === item.href ? 'text-accent bg-gray-50' : 'text-black'
                    }`}
                    aria-current={location.pathname === item.href ? 'page' : undefined}
                  >
                    {item.name}
                  </Disclosure.Button>
                ))}
              </div>
            </nav>
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  )
}

export default Header